import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg_provider/flutter_svg_provider.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/footer/default_footer.dart';
import 'package:softcorp_flutter_core/responsive/responsive.dart';
import 'package:softcorp_flutter_core/split_screen/split_screen.dart';

class MainScreen extends StatelessWidget {
  final Widget? leftChild;
  final Widget rightChild;

  const MainScreen({
    Key? key,
    this.leftChild,
    required this.rightChild,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SplitScreen(
      footerHeight: 200,
      backgroundColor: Colors.white,
      logo: Image.asset(
        "assets/logos/softcorp-color-text.png",
      ),
      lightLogo: Image.asset(
        "assets/logos/softcorp-color-text-white.png",
      ),
      backgroundImage: Image.asset("assets/covers/cover1.jpg"),
      leftChild: leftChild ??
          Center(
            child: Container(
              constraints: Responsive.isDesktop(context)
                  ? BoxConstraints(
                      minHeight: MediaQuery.of(context).size.height - 200)
                  : const BoxConstraints(minHeight: 300),
              padding: const EdgeInsets.all(defaultPadding),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.center,
                children: const [
                  Text(
                    "Softcorp Connect will securely authenticate your credentials",
                    textAlign: TextAlign.center,
                    style: TextStyle(
                        color: Colors.white,
                        fontSize: 25,
                        fontWeight: FontWeight.w400),
                  ),
                  SizedBox(
                    height: defaultPadding,
                  ),
                  Text(
                    "You can view and manage who and what data you have given access to afterwards through our mobile application",
                    textAlign: TextAlign.center,
                    style: TextStyle(
                        color: Colors.white60,
                        fontSize: 18,
                        fontWeight: FontWeight.w400),
                  ),
                ],
              ),
            ),
          ),
      rightChild: rightChild,
      footer: const SizedBox(
        height: 100,
        child: DefaultSoftcorpFooter(),
      ),
    );
  }
}
